@@ -26,7 +26,7 @@ try:
     from tensorflow.keras import Model
     # from tf.keras.layers.normalization import BatchNormalization
 except:
-    print("tensorflow not loaded; Training and prediction will not work")
+    print("tensorflow not loaded; Training will not work")
     tensorflow_keras = False
 
 import h5py
@@ -99,8 +99,8 @@ def model_arch_general(n_bins, n_outputs, kernel_coeff = 0.0005, bias_coeff = 0.
         if param*15 < (2*n_outputs): ## quick hack; make Proper implementation
             param = (n_bins + n_outputs)//2
     else:
-        # param = n_outputs ## More reasonable ???
-        param = n_outputs*2 ## More reasonable ???
+        param = n_outputs ## More reasonable ???
+        # param = n_outputs*2 ## More reasonable ???
         # param = n_bins//2
         
     model = Sequential()
@@ -310,7 +310,7 @@ def predict_DNN(x, wb, temp_key):
     # Second layer
     layer1 = np.dot(layer0, wb[temp_key[3]]) + wb[temp_key[2]] 
     layer1 = np.maximum(0, layer1)
-    # Third layer
+    # Third layer ## ERROR OCCURS
     layer2 = np.dot(layer1, wb[temp_key[5]]) + wb[temp_key[4]]
     layer2 = np.maximum(0, layer2)
     # Output layer
@@ -519,7 +519,7 @@ def predict_CNN_DNN(x, wb, temp_key):
 
 # if __name__ == "__main__":
 #     pass
-    ## test of numpy prediction
+    # # test of numpy prediction
     # codebar = np.load(r"C:\Users\purushot\Desktop\github_version_simple\lauetoolsnn\multi_mat_LaueNN\Zr_alpha_ZrO2_mono\model_Zr_alpha_ZrO2_mono.npz", allow_pickle=True)["arr_0"]
     # prediction = np.load(r"C:\Users\purushot\Desktop\github_version_simple\lauetoolsnn\multi_mat_LaueNN\Zr_alpha_ZrO2_mono\model_Zr_alpha_ZrO2_mono.npz", allow_pickle=True)["arr_1"]
 
